pub struct MaterializedRecord { /* private fields */ }Expand description
One record replacement or deletion applied in the commit metadata transaction.
Implementations
Sourceimpl MaterializedRecord
impl MaterializedRecord
Sourcepub fn upsert(
schema: SchemaDescriptor,
record_id: Vec<u8>,
state: Vec<u8>,
indexes: Vec<IndexValue>,
) -> Result<Self, MaterializedError>
pub fn upsert( schema: SchemaDescriptor, record_id: Vec<u8>, state: Vec<u8>, indexes: Vec<IndexValue>, ) -> Result<Self, MaterializedError>
Validates a complete canonical record replacement and its index values.
Sourcepub fn delete(
schema: SchemaDescriptor,
record_id: Vec<u8>,
) -> Result<Self, MaterializedError>
pub fn delete( schema: SchemaDescriptor, record_id: Vec<u8>, ) -> Result<Self, MaterializedError>
Validates a record deletion under its registered schema.
Sourcepub fn state(&self) -> Option<&[u8]>
pub fn state(&self) -> Option<&[u8]>
Returns complete canonical record state, or None for deletion.
Sourcepub fn indexes(&self) -> &[IndexValue]
pub fn indexes(&self) -> &[IndexValue]
Returns canonical secondary-index values.
Sourcepub fn encode_canonical(&self) -> Result<Vec<u8>, MaterializedError>
pub fn encode_canonical(&self) -> Result<Vec<u8>, MaterializedError>
Encodes the complete rebuildable materialization carried by a commit operation.
Sourcepub fn decode_canonical(bytes: &[u8]) -> Result<Self, MaterializedError>
pub fn decode_canonical(bytes: &[u8]) -> Result<Self, MaterializedError>
Strictly decodes and validates a commit-carried materialization.